==> perl6-gnome-native-0.13.2.tar.gz: perl6-gnome-native-0.13.2/README.md <==
![gtk logo][logo]

# Gnome::N - Native Object and Perl6 - Gnome Interfacing

[![License](http://martimm.github.io/label/License-label.svg)](http://www.perlfoundation.org/artistic_license_2_0)

# Description

This package holds the native object description as well as the interface description to connect to the Gnome libraries. This set modules will never act on their own. They will be used by other packages such as Gnome::Gtk and the like.

## Note
This package is refactored from GTK::V3 at version 0.13.1

## Release notes
* [Release notes][changes]

# Installation of Gnome::N

`zef install Gnome::N`


# Author

Name: **Marcel Timmerman**
Github account name: **MARTIMM**

# Issues

There are always some problems! If you find one please help by filing an issue at [my github project](https://github.com/MARTIMM/perl6-gnome-native/issues).

# Attribution

* The inventors of Perl6 of course and the writers of the documentation which help me out every time again and again.
* The builders of all the Gnome libraries and the documentation.
* Other helpful modules for their insight and use.

[//]: # (---- [refs] ----------------------------------------------------------)
[changes]: https://github.com/MARTIMM/perl6-gnome-native/blob/master/CHANGES.md
[logo]: https://github.com/MARTIMM/perl6-gnome-native/blob/master/doc/images/gtk-logo-100.png




[//]: # (https://nbviewer.jupyter.org/github/MARTIMM/gtk-v3/blob/master/doc/GObject.pdf)
[//]: # (Pod documentation rendered with)
[//]: # (pod-render.pl6 --pdf --g=MARTIMM/gtk-v3 lib)

==> perl6-gnome-native-0.15.1.1.tar.gz: perl6-gnome-native-0.15.1.1/README.md <==
![gtk logo][logo]

# Gnome::N - Native Object and Perl6 - Gnome Interfacing

[![License](http://martimm.github.io/label/License-label.svg)](http://www.perlfoundation.org/artistic_license_2_0)

# Description

This package holds the native object description as well as the interface description to connect to the Gnome libraries. This set of modules will never act on their own. They will be used by other packages such as `Gnome::Gtk3` and the like.

## Note
This package is refactored from GTK::V3 at version 0.13.1

## Release notes
* [Release notes][changes]

# Installation
Do not install this package on its own. Instead install `Gnome::Gtk3`.

`zef install Gnome::Gtk3`


# Author

Name: **Marcel Timmerman**
Github account name: **MARTIMM**

# Issues

There are always some problems! If you find one please help by filing an issue at [my Gnome::Gtk3 github project][issues].

# Attribution

* The inventors of Perl6 of course and the writers of the documentation which help me out every time again and again.
* The builders of all the Gnome libraries and the documentation.
* Other helpful modules for their insight and use.

[//]: # (---- [refs] ----------------------------------------------------------)
[changes]: https://github.com/MARTIMM/perl6-gnome-native/blob/master/CHANGES.md
[logo]: https://github.com/MARTIMM/perl6-gnome-native/blob/master/doc/images/gtk-logo-100.png
[issues]: https://github.com/MARTIMM/perl6-gnome-gtk3/issues



[//]: # (https://nbviewer.jupyter.org/github/MARTIMM/gtk-v3/blob/master/doc/GObject.pdf)
[//]: # (Pod documentation rendered with)
[//]: # (pod-render.pl6 --pdf --g=MARTIMM/gtk-v3 lib)
